package com.me.asteroids.systems;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.Polygon;
import com.me.asteroids.Graphics;
import com.me.asteroids.components.ModelComponent;
import com.me.common.ecs.ComponentMapper;
import com.me.common.ecs.Engine;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class ModelRenderSystem extends EntitySystem {

    private ComponentMapper<ModelComponent> modelMapper;

    private ShapeRenderer renderer;

    public ModelRenderSystem(Engine engine, Graphics graphics) {
        super(engine, ModelComponent.class);
        this.modelMapper = engine.getComponentMapper(ModelComponent.class);
        this.renderer = graphics.getShapeRenderer();
    }

    @Override
    public void preProcessing() {
        renderer.setColor(Color.WHITE);
        renderer.begin(ShapeRenderer.ShapeType.Line);
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        ModelComponent modelComponent = modelMapper.get(entity);

        Polygon model = modelComponent.model;
        renderer.polygon(model.getTransformedVertices());
    }

    @Override
    public void postProcessing() {
        renderer.end();
    }

}
